@@ -98,7 +98,7 @@ There are the following methods for internal use within this module:
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "/src/script/src/engine/SCons/Builder.py none 2019-08-08 09:09:12 none"
+__revision__ = "/src/script/src/engine/SCons/Builder.py none 2019-12-17 03:06:27 none"
 
 import collections
 
@@ -396,16 +396,13 @@ class BuilderBase(object):
         self.env = env
         self.single_source = single_source
         if 'overrides' in overrides:
-            SCons.Warnings.warn(SCons.Warnings.DeprecatedBuilderKeywordsWarning,
-                "The \"overrides\" keyword to Builder() creation has been deprecated;\n" +\
-                "\tspecify the items as keyword arguments to the Builder() call instead.")
-            overrides.update(overrides['overrides'])
-            del overrides['overrides']
+            msg =  "The \"overrides\" keyword to Builder() creation has been removed;\n" +\
+                "\tspecify the items as keyword arguments to the Builder() call instead."
+            raise TypeError(msg)
         if 'scanner' in overrides:
-            SCons.Warnings.warn(SCons.Warnings.DeprecatedBuilderKeywordsWarning,
-                                "The \"scanner\" keyword to Builder() creation has been deprecated;\n"
-                                "\tuse: source_scanner or target_scanner as appropriate.")
-            del overrides['scanner']
+            msg = "The \"scanner\" keyword to Builder() creation has been removed;\n" +\
+                "\tuse: source_scanner or target_scanner as appropriate."
+            raise TypeError(msg)
         self.overrides = overrides
 
         self.set_suffix(suffix)
