@@ -43,7 +43,7 @@ from __future__ import print_function
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "/src/script/src/engine/SCons/Node/__init__.py none 2019-08-08 09:09:12 none"
+__revision__ = "/src/script/src/engine/SCons/Node/__init__.py none 2019-12-17 03:06:27 none"
 
 import os
 import collections
@@ -614,6 +614,7 @@ class Node(object, with_metaclass(NoSlotsPyPy)):
         self._func_rexists = 1
         self._func_get_contents = 0
         self._func_target_from_source = 0
+        self.ninfo = None
 
         self.clear_memoized_values()
 
@@ -1131,11 +1132,10 @@ class Node(object, with_metaclass(NoSlotsPyPy)):
         return ninfo
 
     def get_ninfo(self):
-        try:
-            return self.ninfo
-        except AttributeError:
-            self.ninfo = self.new_ninfo()
+        if self.ninfo is not None:
             return self.ninfo
+        self.ninfo = self.new_ninfo()
+        return self.ninfo
 
     def new_binfo(self):
         binfo = self.BuildInfo()
