@@ -38,7 +38,7 @@ deprecated_python_version = (2, 7, 0)
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "/src/script/src/engine/SCons/Script/Main.py none 2019-08-08 01:09:12 none"
+__revision__ = "/src/script/src/engine/SCons/Script/Main.py none 2019-12-17 03:06:27 none"
 
 
 import SCons.compat
@@ -75,6 +75,7 @@ print_objects = 0
 print_memoizer = 0
 print_stacktrace = 0
 print_time = 0
+print_action_timestamps = 0
 sconscript_time = 0
 cumulative_command_time = 0
 exit_status = 0   # final exit status, assume success by default
@@ -209,6 +210,9 @@ class BuildTask(SCons.Taskmaster.OutOfDateTask):
             finish_time = time.time()
             last_command_end = finish_time
             cumulative_command_time = cumulative_command_time+finish_time-start_time
+            if print_action_timestamps:
+                sys.stdout.write("Command execution start timestamp: %s: %f\n"%(str(self.node), start_time))
+                sys.stdout.write("Command execution end timestamp: %s: %f\n"%(str(self.node), finish_time))
             sys.stdout.write("Command execution time: %s: %f seconds\n"%(str(self.node), finish_time-start_time))
 
     def do_failed(self, status=2):
@@ -636,7 +640,7 @@ def _SConstruct_exists(dirname='', repositories=[], filelist=None):
     return None
 
 def _set_debug_values(options):
-    global print_memoizer, print_objects, print_stacktrace, print_time
+    global print_memoizer, print_objects, print_stacktrace, print_time, print_action_timestamps
 
     debug_values = options.debug
 
@@ -674,6 +678,9 @@ def _set_debug_values(options):
         options.tree_printers.append(TreePrinter(status=True))
     if "time" in debug_values:
         print_time = 1
+    if "action-timestamps" in debug_values:
+        print_time = 1
+        print_action_timestamps = 1
     if "tree" in debug_values:
         options.tree_printers.append(TreePrinter())
     if "prepare" in debug_values:
