@@ -54,7 +54,7 @@ __doc__ = """
         target(s) that it decides need to be evaluated and/or built.
 """
 
-__revision__ = "/src/script/src/engine/SCons/Taskmaster.py none 2019-08-08 09:09:12 none"
+__revision__ = "/src/script/src/engine/SCons/Taskmaster.py none 2019-12-17 03:06:27 none"
 
 from itertools import chain
 import operator
@@ -874,8 +874,10 @@ class Taskmaster(object):
             # These nodes have not even been visited yet.  Add
             # them to the list so that on some next pass we can
             # take a stab at evaluating them (or their children).
-            children_not_visited.reverse()
-            self.candidates.extend(self.order(children_not_visited))
+            if children_not_visited:
+                if len(children_not_visited) > 1:
+                    children_not_visited.reverse()
+                self.candidates.extend(self.order(children_not_visited))
 
             # if T and children_not_visited:
             #    T.write(self.trace_message('     adding to candidates: %s' % map(str, children_not_visited)))
