@@ -25,7 +25,7 @@ The msi packager.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "/src/script/src/engine/SCons/Tool/packaging/msi.py none 2019-08-08 09:09:12 none"
+__revision__ = "/src/script/src/engine/SCons/Tool/packaging/msi.py none 2019-12-17 03:06:27 none"
 
 import os
 import SCons
@@ -224,7 +224,7 @@ def build_wxsfile(target, source, env):
 # setup function
 #
 def create_default_directory_layout(root, NAME, VERSION, VENDOR, filename_set):
-    """ Create the wix default target directory layout and return the innermost
+    r""" Create the wix default target directory layout and return the innermost
     directory.
 
     We assume that the XML tree delivered in the root argument already contains
