@@ -32,7 +32,7 @@ from __future__ import print_function
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "/src/script/src/engine/SCons/Tool/swig.py none 2019-08-08 09:09:12 none"
+__revision__ = "/src/script/src/engine/SCons/Tool/swig.py none 2019-12-17 03:06:27 none"
 
 import os.path
 import sys
@@ -80,7 +80,7 @@ def _find_modules(src):
 
     for m in matches:
         mnames.append(m[2])
-        directors = directors or m[0].find('directors') >= 0
+        directors = directors or 'directors' in m[0]
     return mnames, directors
 
 def _add_director_header_targets(target, env):
