@@ -33,7 +33,7 @@ selection method.
 #
 from __future__ import print_function
 
-__revision__ = "/src/script/src/engine/SCons/Tool/tex.py none 2019-08-08 01:09:12 none"
+__revision__ = "/src/script/src/engine/SCons/Tool/tex.py none 2019-12-17 03:06:27 none"
 
 import os.path
 import re
@@ -297,8 +297,8 @@ def InternalLaTeXAuxAction(XXXLaTeXAction, target = None, source= None, env=None
         logfilename = targetbase + '.log'
         logContent = ''
         if os.path.isfile(logfilename):
-            with open(logfilename, "r") as f:
-                logContent = f.read()
+            with open(logfilename, "rb") as f:
+                logContent = f.read().decode(errors='replace')
 
 
         # Read the fls file to find all .aux files
