@@ -27,7 +27,7 @@ This file implements the warnings framework for SCons.
 
 """
 
-__revision__ = "/src/script/src/engine/SCons/Warnings.py none 2019-08-08 09:09:12 none"
+__revision__ = "/src/script/src/engine/SCons/Warnings.py none 2019-12-17 03:06:27 none"
 
 import sys
 
@@ -120,33 +120,15 @@ class PythonVersionWarning(DeprecatedWarning):
 class DeprecatedSourceCodeWarning(FutureDeprecatedWarning):
     pass
 
-class DeprecatedBuildDirWarning(DeprecatedWarning):
-    pass
-
 class TaskmasterNeedsExecuteWarning(DeprecatedWarning):
     pass
 
-class DeprecatedCopyWarning(MandatoryDeprecatedWarning):
-    pass
-
 class DeprecatedOptionsWarning(MandatoryDeprecatedWarning):
     pass
 
-class DeprecatedSourceSignaturesWarning(MandatoryDeprecatedWarning):
-    pass
-
-class DeprecatedTargetSignaturesWarning(MandatoryDeprecatedWarning):
-    pass
-
 class DeprecatedDebugOptionsWarning(MandatoryDeprecatedWarning):
     pass
 
-class DeprecatedSigModuleWarning(MandatoryDeprecatedWarning):
-    pass
-
-class DeprecatedBuilderKeywordsWarning(MandatoryDeprecatedWarning):
-    pass
-
 class DeprecatedMissingSConscriptWarning(DeprecatedWarning):
     pass
 
